@@ -64,6 +64,7 @@ est = timezone(timedelta(hours=-5), 'UTC')
 
 dtime = namedtuple('dtime', ('values', 'units', 'calendar'))
 dateformat =  '%Y-%m-%d %H:%M:%S'
+dateformat2 =  '%y-%m-%d %H:%M:%S'
 
 calendars=['standard', 'gregorian', 'proleptic_gregorian', 'noleap', 'julian',\
            'all_leap', '365_day', '366_day', '360_day']
@@ -201,6 +202,8 @@ class cftimeTestCase(unittest.TestCase):
         # check num2date method.
         d2 = self.cdftime_pg.num2date(t1)
         self.assertTrue(d.strftime(dateformat) == d2.strftime(dateformat))
+        # make sure two digit years work in strftime (issue #362)
+        self.assertTrue(d.strftime(dateformat2) == d2.strftime(dateformat2))
         # check day of year.
         ndayr = d.timetuple()[7]
         self.assertTrue(ndayr == 125)
@@ -943,6 +946,16 @@ class cftimeTestCase(unittest.TestCase):
         times = np.array([1,2,3,np.inf],dtype=np.float64)
         result = cftime.num2date(times, 'days since 2000-01-01', 'standard')
         np.testing.assert_equal(result, expected)
+        # issue #354: roundtrip not correct when dates are all python datetime
+        # instances and calendar not proleptic_gregorian.
+        datesin = np.array(["0002"],
+                  dtype="datetime64[s]").astype("M8[us]").astype(datetime)
+        datein = datesin.item()
+        num = cftime.date2num(datein, "seconds since 2000-01-01", calendar='standard')
+        dateout = cftime.num2date(num, "seconds since 2000-01-01", calendar='standard')
+        dateout2 = cftime.datetime(datein.year, datein.month, datein.day,
+                   calendar='standard')
+        assert(dateout==dateout2)
 
 
 class TestDate2index(unittest.TestCase):
